aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTom Ryder <tom@sanctum.geek.nz>2022-08-14 13:44:12 +1200
committerTom Ryder <tom@sanctum.geek.nz>2022-08-14 16:20:22 +1200
commit9c36e24cb53f145fc5fa1c1ba89cfa8a2b8aa902 (patch)
tree8ae9f15c8e70bd36806fe1d0f16d11b2739a1ed4
parentMerge branch 'release/v12.21.0' into develop (diff)
downloaddotfiles-9c36e24cb53f145fc5fa1c1ba89cfa8a2b8aa902.tar.gz
dotfiles-9c36e24cb53f145fc5fa1c1ba89cfa8a2b8aa902.zip
Revert "Refactor X startup to accomodate differ...
This didn't work at all. LightDM on Debian doesn't look at ~/.xprofile. Need a better method. This reverts commit ad1ce4ce7da62d2bf23c1f6ed60919b55ed02f58.
-rw-r--r--x/xsession.sh49
-rw-r--r--x/xsessionrc6
2 files changed, 16 insertions, 39 deletions
diff --git a/x/xsessionrc b/x/xsessionrc
deleted file mode 100644
index 48f2a725..00000000
--- a/x/xsessionrc
+++ /dev/null
@@ -1,6 +0,0 @@
-# X startup commands go in here if they should run on every X session, whether
-# classic `startx` or a modern DE like LightDM
-
-# Update BROWSER, since .profile has already set this to a curses browser
-# shellcheck disable=SC2034
-BROWSER=x-www-browser
diff --git a/x/xsession.sh b/x/xsession.sh
index e0552315..6b298048 100644
--- a/x/xsession.sh
+++ b/x/xsession.sh
@@ -1,20 +1,8 @@
-#
-# Custom i3wm X session to fit into Debian's way of doing things, for use with
-# startx(1) or xinit(1). From Debian's `man 1 startx` (xinit dpkg 1.4.0-1):
-#
-# > Note that in the Debian system, what many people traditionally put in the
-# > .xinitrc file should go in .xsession instead; this permits the same X
-# > environment to be presented whether startx, xdm, or xinit is used to start
-# > the X session. All discussion of the .xinitrc file in the xinit(1) manual
-# > page applies equally well to .xsession.
-#
-# This turns out to be important for having the X session wrappers in /etc/X11
-# on Debian-derived systems do things like dbus daemon and accessibility setup.
-#
-# At the time of writing, none of my machines running X are using anything
-# other than the Debian-derived X startup script layout, so we'll just conform
-# to that unless and until I actually need to abstract this.
-#
+# Custom X session to fit into Debian's way of doing things
+
+# Load common environment variables
+# shellcheck disable=SC1091
+. "$HOME"/.xprofile
# Monitor and wallpaper setup is very machine-specific, and isn't versioned in
# here. Neither xrandr(1) nor xwallpaper(1) have config files, so we fake it
@@ -42,20 +30,14 @@ xset \
mouse 5/2 0 \
s off
-# Start a few daemons if we can; it's OK if any of these don't exist, but we'll
-# log the failed attempt to start them to the errors file, as a hint that
-# I might want to install them.
-#
-(
- # Display compositor
- compton
- # Message display (libnotify)
- dunst
- # PulseAudio system tray tool
- pasystray
- # Hide mouse after inactivity
- unclutter
-) &
+# Start a few daemons if we can; it's OK if they don't exist, but log the
+# failed attempt to start them to the errors file.
+## compton: Display compositor
+compton -b &
+## dunst: Message display (libnotify)
+dunst &
+## unclutter: Hide mouse after inactivity (but not on root window)
+unclutter -idle 5 &
# Load all supplementary scripts in ~/.xsession.d
for sh in "$HOME"/.xsession.d/*.sh ; do
@@ -64,5 +46,6 @@ for sh in "$HOME"/.xsession.d/*.sh ; do
done
unset -v sh
-# Become an i3 window manager process, having set everything else up
-exec i3
+# Start Debian's configured window manager now that everything's ready; at the
+# time of writing, this is normally i3wm
+exec x-window-manager